@@ -10,17 +10,28 @@
 #' @param agemax age of oldest vehicles for that category
 #' @param k multiplication factor
 #' @param bystreet when TRUE it is expecting that 'a' and 'b' are numeric vectors with length equal to x
+#' @param net SpatialLinesDataFrame or Spatial Feature of "LINESTRING"
 #' @param message message with average age and total numer of vehicles
 #' @return dataframe of age distrubution of vehicles
+#' @importFrom sf st_sf st_as_sf
 #' @export
 #' @examples {
-#' lt <- Vehicles(rnorm(100, 300, 10))
-#' LT_B5 <- age_hdv(x = lt,name = "LT_B5")
+#' data(net)
+#' LT_B5 <- age_hdv(x = net$hdv,name = "LT_B5")
+#' plot(LT_B5)
+#' LT_B5 <- age_hdv(x = net$hdv, name = "LT_B5", net = net)
 #' plot(LT_B5)
-#'
 #' }
-age_hdv <- function (x, name, a = 0.2, b = 17, agemin = 1, agemax = 50, k = 1,
-                     bystreet = F, message = TRUE){
+age_hdv <- function (x,
+                     name = "veh",
+                     a = 0.2,
+                     b = 17,
+                     agemin = 1,
+                     agemax = 50,
+                     k = 1,
+                     bystreet = F,
+                     net,
+                     message = TRUE){
   if (missing(x) | is.null(x)) {
     stop (print("Missing vehicles"))
   } else if (bystreet == T){
@@ -55,7 +66,15 @@ age_hdv <- function (x, name, a = 0.2, b = 17, agemin = 1, agemax = 50, k = 1,
                   sep=" ")
     )
     cat("\n")
-}
+    }
+    if(!missing(net)){
+      netsf <- sf::st_as_sf(net)
+      dfsf <- sf::st_sf(Vehicles(df*k), geometry = netsf$geometry)
+      return(dfsf)
+    } else {
+      return(Vehicles(df*k))
+    }
+
   } else {
     suca <- function (t) {1/(1 + exp(a*(t+b)))+1/(1 + exp(a*(t-b)))}
     anos <- seq(agemin,agemax)
@@ -78,7 +97,13 @@ age_hdv <- function (x, name, a = 0.2, b = 17, agemin = 1, agemax = 50, k = 1,
                   sep=" ")
     )
     cat("\n")
-  } }
-  df <- Vehicles(df*k)
-  return(df)
+    }
+    if(!missing(net)){
+      netsf <- sf::st_as_sf(net)
+      dfsf <- sf::st_sf(Vehicles(df*k), geometry = netsf$geometry)
+      return(dfsf)
+    } else {
+      return(Vehicles(df*k))
+    }
+    }
 }
