@@ -3,21 +3,33 @@
 #' @description \code{my_age} returns amount of vehicles at each age using a
 #' numeric vector.
 #'
-#' @param x numerical vector of vehicles.
-#' @param y Age dustribution of vehicles.
+#' @param x Numeric; vehicles by street (or spatial feature).
+#' @param y Numeric; vehicles by age of use
 #' @param name of vehicle assigned to columns of dataframe.
 #' @param k multiplication factor.
+#' @param net SpatialLinesDataFrame or Spatial Feature of "LINESTRING"
 #' @param message message with average age and total numer of vehicles.
 #' @return dataframe of age distrubution of vehicles.
+#' @importFrom sf st_sf st_as_sf
 #' @export
 #' @examples {
-#' # Do not run
-#' pc <- rnorm(100, 300, 10)
-#' dpc <- c(rnorm(10, 99, 1), NA, NA, NA)
-#' PC_E25_1400 <- my_age(x = pc, y = dpc, name = "PC_E25_1400")
+#' data(net)
+#' dpc <- c(seq(1,20,3), 20:10)
+#' PC_E25_1400 <- my_age(x = net$ldv, y = dpc, name = "PC_E25_1400")
+#' class(PC_E25_1400)
 #' plot(PC_E25_1400)
+#' PC_E25_1400sf <- my_age(x = net$ldv, y = dpc, name = "PC_E25_1400", net = net)
+#' class(PC_E25_1400sf)
+#' plot(PC_E25_1400sf)
+#' PC_E25_1400nsf <- sf::st_set_geometry(PC_E25_1400sf, NULL)
+#' class(PC_E25_1400nsf)
 #' }
-my_age <- function (x, y, name,  k = 1, message = TRUE){
+my_age <- function (x,
+                    y,
+                    name = "veh",
+                    k = 1,
+                    net,
+                    message = TRUE){
   if (missing(x) | is.null(x)) {
     stop (print("Missing vehicles"))
     } else if (missing(y) | is.null(y)) {
@@ -39,5 +51,11 @@ my_age <- function (x, y, name,  k = 1, message = TRUE){
     cat("\n")
     }}
   df <- Vehicles(df*k)
-  return(df)
+  if(!missing(net)){
+    netsf <- sf::st_as_sf(net)
+    dfsf <- sf::st_sf(df, geometry = netsf$geometry)
+    return(dfsf)
+  } else {
+    return(df)
+  }
 }
